==> ckan-2.5.3.tar.gz: ckan-2.5.3/ckan/public/base/i18n/es.js <==
{
  "": {
    "domain": "ckan",
    "lang": "es",
    "plural-forms": "nplurals=2; plural=(n != 1);"
  },
  "An Error Occurred": [
    null,
    "Ocurrió un error"
  ],
  "An error occurred: %(text)s %(error)s": [
    null,
    "Se ha producido un error: %(text)s %(error)s"
  ],
  "Are you sure you want to perform this action?": [
    null,
    "¿Está seguro de que desea realizar esta acción?"
  ],
  "Cancel": [
    null,
    "Cancelar"
  ],
  "Confirm": [
    null,
    "Confirmar"
  ],
  "Edit": [
    null,
    "Editar"
  ],
  "Failed to load data API information": [
    null,
    "Falló carga de información de datos de API"
  ],
  "Follow": [
    null,
    "Seguir"
  ],
  "Hide": [
    null,
    "Esconder"
  ],
  "Image": [
    null,
    "Imagen"
  ],
  "Input is too short, must be at least one character": [
    null,
    "Ingreso es muy corto, debe tener al menos un caracter"
  ],
  "Link": [
    null,
    "Enlace"
  ],
  "Link to a URL on the internet (you can also link to an API)": [
    null,
    "Enlazar a una URL de internet (también puede enlazar a una API)"
  ],
  "Loading...": [
    null,
    "Cargando ..."
  ],
  "No matches found": [
    null,
    "No se encontraron coincidencias"
  ],
  "Please Confirm Action": [
    null,
    "Por favor confirme la acción"
  ],
  "Remove": [
    null,
    "Quitar"
  ],
  "Reorder resource view": [
    null,
    "Reordenar vista de recurso"
  ],
  "Reorder resources": [
    null,
    "Reordenar recursos"
  ],
  "Resource uploaded": [
    null,
    "Recurso subido"
  ],
  "Save order": [
    null,
    "Guardar orden"
  ],
  "Saving...": [
    null,
    "Guardando..."
  ],
  "Show more": [
    null,
    "Mostrar más"
  ],
  "Start typing…": [
    null,
    "Comience a escribir..."
  ],
  "There are unsaved modifications to this form": [
    null,
    "Existen modificaciones no guardadas para este formulario"
  ],
  "There is no API data to load for this resource": [
    null,
    "No existen datos de API para cargar para este recurso"
  ],
  "URL": [
    null,
    "URL"
  ],
  "Unable to authenticate upload": [
    null,
    "No se pudo autenticar subida"
  ],
  "Unable to get data for uploaded file": [
    null,
    "No se pudo obtener datos para el archivo subido"
  ],
  "Unable to upload file": [
    null,
    "No se pudo subir el archivo"
  ],
  "Unfollow": [
    null,
    "Dejar de seguir"
  ],
  "Upload": [
    null,
    "Subir"
  ],
  "Upload a file": [
    null,
    "Sube un archivo"
  ],
  "Upload a file on your computer": [
    null,
    "Subir un fichero a su PC"
  ],
  "You are uploading a file. Are you sure you want to navigate away and stop this upload?": [
    null,
    "Estás subiendo un fichero. Estás seguro que quieres salir y parar esta subida?"
  ],
  "error loading view": [
    null,
    "error cargando la vista"
  ],
  "show less": [
    null,
    "mostrar menos"
  ],
  "show more": [
    null,
    "mostrar más"
  ]
}

==> ckan-2.6.0.tar.gz: ckan-2.6.0/ckan/public/base/i18n/es.js <==
{
  "": {
    "domain": "ckan",
    "lang": "es",
    "plural-forms": "nplurals=2; plural=(n != 1);"
  },
  "An Error Occurred": [
    null,
    "Ocurrió un error"
  ],
  "An error occurred: %(text)s %(error)s": [
    null,
    "Ha ocurrido un error: %(text)s %(error)s"
  ],
  "Are you sure you want to perform this action?": [
    null,
    "¿Está seguro de que desea realizar esta acción?"
  ],
  "Cancel": [
    null,
    "Cancelar"
  ],
  "Confirm": [
    null,
    "Confirmar"
  ],
  "Edit": [
    null,
    "Editar"
  ],
  "Failed to load data API information": [
    null,
    "Falló carga de información de datos de API"
  ],
  "File": [
    null,
    "Fichero"
  ],
  "Follow": [
    null,
    "Seguir"
  ],
  "Hide": [
    null,
    "Esconder"
  ],
  "Image": [
    null,
    "Imagen"
  ],
  "Input is too short, must be at least one character": [
    null,
    "Ingreso es muy corto, debe tener al menos un caracter"
  ],
  "Link": [
    null,
    "Enlace"
  ],
  "Link to a URL on the internet (you can also link to an API)": [
    null,
    "Enlazar a una URL de internet (también puede enlazar a una API)"
  ],
  "Loading...": [
    null,
    "Cargando ..."
  ],
  "No matches found": [
    null,
    "No se encontraron coincidencias"
  ],
  "Please Confirm Action": [
    null,
    "Por favor confirme la acción"
  ],
  "Remove": [
    null,
    "Quitar"
  ],
  "Reorder resource view": [
    null,
    "Reordenar vista de recurso"
  ],
  "Reorder resources": [
    null,
    "Reordenar recursos"
  ],
  "Resource uploaded": [
    null,
    "Recurso subido"
  ],
  "Save order": [
    null,
    "Guardar orden"
  ],
  "Saving...": [
    null,
    "Guardando..."
  ],
  "Show more": [
    null,
    "Mostrar más"
  ],
  "Start typing…": [
    null,
    "Comience a escribir..."
  ],
  "There are unsaved modifications to this form": [
    null,
    "Existen modificaciones no guardadas para este formulario"
  ],
  "There is no API data to load for this resource": [
    null,
    "No existen datos de API para cargar para este recurso"
  ],
  "URL": [
    null,
    "URL"
  ],
  "Unable to authenticate upload": [
    null,
    "No se pudo autenticar subida"
  ],
  "Unable to get data for uploaded file": [
    null,
    "No se pudo obtener datos para el archivo subido"
  ],
  "Unable to upload file": [
    null,
    "No se pudo subir el archivo"
  ],
  "Unfollow": [
    null,
    "Dejar de seguir"
  ],
  "Upload": [
    null,
    "Subir"
  ],
  "Upload a file": [
    null,
    "Sube un archivo"
  ],
  "Upload a file on your computer": [
    null,
    "Subir un fichero a su PC"
  ],
  "You are uploading a file. Are you sure you want to navigate away and stop this upload?": [
    null,
    "Estás subiendo un fichero. Estás seguro que quieres salir y parar esta subida?"
  ],
  "error loading view": [
    null,
    "error cargando la vista"
  ]
}
